cmd

package
v1.2.2 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jan 21, 2026 License: MIT Imports: 12 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Execute

func Execute(version string) error

Types

type ConfigCmd added in v0.0.16

type ConfigCmd struct {
	*ConfigListCmd   `arg:"subcommand:list"`
	*ConfigRenameCmd `arg:"subcommand:rename"`
	*ConfigDeleteCmd `arg:"subcommand:delete"`
	FolderPath       string `arg:"-p,--path" default:"." help:"Local path where the .ska-config folder is located"`
}

func (*ConfigCmd) Execute added in v0.0.16

func (c *ConfigCmd) Execute(ctx context.Context) error

type ConfigDeleteCmd added in v0.0.16

type ConfigDeleteCmd struct {
	Name        string `arg:"-n,--name,required" help:"The name of the named configuration to delete"`
	AutoApprove bool   `arg:"-y,--auto-approve" help:"Skip the confirmation prompt"`
}

func (*ConfigDeleteCmd) Execute added in v0.0.16

func (c *ConfigDeleteCmd) Execute(ctx context.Context) error

type ConfigListCmd added in v0.0.16

type ConfigListCmd struct {
}

func (*ConfigListCmd) Execute added in v0.0.16

func (c *ConfigListCmd) Execute(ctx context.Context) error

type ConfigListResultItem added in v0.0.16

type ConfigListResultItem struct {
	NamedConfig string `json:"NamedConfig" csv:"NamedConfig"`
	LastUpdate  string `json:"LastUpdate" csv:"LastUpdate"`
}

type ConfigRenameCmd added in v0.0.16

type ConfigRenameCmd struct {
	Name    string `arg:"-o,--name,required" help:"The name of the named configuration to rename"`
	NewName string `arg:"-n,--new-name,required" help:"The new name to give to the named configuration"`
}

func (*ConfigRenameCmd) Execute added in v0.0.16

func (c *ConfigRenameCmd) Execute(ctx context.Context) error

type CreateCmd

type CreateCmd struct {
	TemplateURI     string            `arg:"-b,--blueprint,required" help:"URI of the template blueprint to use"`
	DestinationPath string            `arg:"-o,--output" default:"." help:"Destination path where to expand the blueprint"`
	NamedConfig     string            `arg:"-n,--name" help:"The ska configuration name in case there are multiple templates configurations in the same root"`
	Variables       map[string]string `arg:"-v,separate" help:"Variables to use in the template. Can be specified multiple times"`
	NonInteractive  bool              `arg:"-n,--non-interactive" help:"Run in non-interactive mode"`
}

func (*CreateCmd) Execute

func (c *CreateCmd) Execute(ctx context.Context) error

type UpdateCmd

type UpdateCmd struct {
	FolderPath     string            `arg:"-p,--path" default:"." help:"Local path where the .ska-config folder is located"`
	NamedConfig    string            `arg:"-n,--name" help:"The ska configuration name in case there are multiple templates configurations in the same root"`
	Variables      map[string]string `arg:"-v,separate" help:"Variables to use in the template. Can be specified multiple times"`
	NonInteractive bool              `arg:"-n,--non-interactive" help:"Run in non-interactive mode"`
}

func (*UpdateCmd) Execute

func (c *UpdateCmd) Execute(ctx context.Context) error

Jump to