Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
Types ¶
type ConfigCmd ¶ added in v0.0.16
type ConfigCmd struct {
*ConfigListCmd `arg:"subcommand:list"`
*ConfigRenameCmd `arg:"subcommand:rename"`
*ConfigDeleteCmd `arg:"subcommand:delete"`
FolderPath string `arg:"-p,--path" default:"." help:"Local path where the .ska-config folder is located"`
}
type ConfigDeleteCmd ¶ added in v0.0.16
type ConfigListCmd ¶ added in v0.0.16
type ConfigListCmd struct {
}
type ConfigListResultItem ¶ added in v0.0.16
type ConfigRenameCmd ¶ added in v0.0.16
type CreateCmd ¶
type CreateCmd struct {
TemplateURI string `arg:"-b,--blueprint,required" help:"URI of the template blueprint to use"`
DestinationPath string `arg:"-o,--output" default:"." help:"Destination path where to expand the blueprint"`
NamedConfig string `arg:"-n,--name" help:"The ska configuration name in case there are multiple templates configurations in the same root"`
Variables map[string]string `arg:"-v,separate" help:"Variables to use in the template. Can be specified multiple times"`
NonInteractive bool `arg:"-n,--non-interactive" help:"Run in non-interactive mode"`
}
type UpdateCmd ¶
type UpdateCmd struct {
FolderPath string `arg:"-p,--path" default:"." help:"Local path where the .ska-config folder is located"`
NamedConfig string `arg:"-n,--name" help:"The ska configuration name in case there are multiple templates configurations in the same root"`
Variables map[string]string `arg:"-v,separate" help:"Variables to use in the template. Can be specified multiple times"`
NonInteractive bool `arg:"-n,--non-interactive" help:"Run in non-interactive mode"`
}
Click to show internal directories.
Click to hide internal directories.